@@ -34,7 +34,7 @@ class DefaultNetworkHandler:
         position = "(%s, %s, %s)" % (x, y, z)
         self.log.debug("Location "+str(id)+" of population: "+population_id+", component: "+component+": "+position)
         
-
+    
     #
     #  Internal info method, can be reused in overriding classes for debugging
     #        
@@ -50,7 +50,13 @@ class DefaultNetworkHandler:
         sizeInfo = " size: "+ str(size)+ " cells"
         self.log.debug("Input Source: "+inputName+", on population: "+population_id+sizeInfo+" with component: "+ component)
         
-    
+    # Temp for older API version
+    def printLocationInformation(self, id, population_id, component, x, y, z):
+        return self.print_location_information(id, population_id, component, x, y, z)
+    def printConnectionInformation(self,  projName, id, prePop, postPop, synapseType, preCellId, postCellId, weight):
+        return self.print_connection_information(projName, id, prePop, postPop, synapseType, preCellId, postCellId, weight)
+    def printInputInformation(self, inputName, population_id, component, size=-1):
+        return self.print_input_information(inputName, population_id, component, size)
 
     #
     #  Should be overridden
@@ -75,7 +81,7 @@ class DefaultNetworkHandler:
     #
     #  Should be overridden to create population array
     #  
-    def handle_population(self, population_id, component, size=-1, component_obj=None, properties={}):
+    def handle_population(self, population_id, component, size=-1, component_obj=None, properties={}, notes=None):
         sizeInfo = " as yet unspecified size"
         if size>=0:
             sizeInfo = " size: "+ str(size)+ " cells"
@@ -110,7 +116,7 @@ class DefaultNetworkHandler:
         if pre_synapse_obj:
             synInfo += " (pre comp: %s)"%pre_synapse_obj.__class__.__name__
 
-        self.log.debug("Projection: "+projName+" ("+type+") from "+prePop+" to "+postPop+" with syn: "+synapse+synInfo)
+        self.log.debug("Projection: "+projName+" ("+type+") from "+prePop+" to "+postPop+" with syn: %s%s"%(synapse,synInfo))
 
 
     #
